@@ -1,6 +1,6 @@
 use http::Method;
 pub(crate) use http::{header, HeaderValue, Request};
-use longbridge_httpcli::{HttpClient, HttpClientConfig};
+use longbridge_httpcli::{HttpClient, HttpClientConfig, Json};
 use serde::{Deserialize, Serialize};
 use time::OffsetDateTime;
 use tokio_tungstenite::tungstenite::client::IntoClientRequest;
@@ -82,10 +82,6 @@ impl Config {
             language: Language::EN,
         };
 
-        if let Ok(http_url) = std::env::var("LONGBRIDGE_HTTP_URL") {
-            config.http_cli_config = config.http_cli_config.http_url(http_url);
-        }
-
         if let Ok(quote_ws_url) = std::env::var("LONGBRIDGE_QUOTE_WS_URL") {
             config.quote_ws_url = quote_ws_url;
         }
@@ -198,9 +194,10 @@ impl Config {
             .create_http_client()
             .request(Method::GET, "/v1/token/refresh")
             .query_params(request)
-            .response::<Response>()
+            .response::<Json<Response>>()
             .send()
             .await?
+            .0
             .token;
         Ok(new_token)
     }
